@@ -4,8 +4,6 @@
 #'
 #' The estimates were calculated by DataSUS (Brazilian Ministry of Health), manually downloaded from DataSUS website, and organized as a tibble.
 #'
-#' More details about the estimation methodology may be found here: \url{http://tabnet.datasus.gov.br/cgi/POPSVS/NT-POPULACAO-RESIDENTE-2000-2021.PDF}
-#'
 #' \describe{
 #'   \item{uf}{UF 2 digits code}
 #'   \item{year}{year of the estimative}
@@ -21,6 +19,9 @@
 uf_pop_totals <- function(){
 res <- dplyr::bind_rows(brpop::uf_male_pop, brpop::uf_female_pop) %>%
     dplyr::filter(.data$age_group == "Total") %>%
+    dplyr::group_by(.data$uf, .data$year) %>%
+    dplyr::summarise(pop = sum(.data$pop)) %>%
+    dplyr::ungroup() %>%
     dplyr::arrange(.data$uf, .data$year)
 
   return(res)
